User Guide
==========

The user guide provides an overview of **Colour** and explains important
concepts and features, details can be found in the `API Reference <reference.html>`__.

.. toctree::
    :maxdepth: 1

    Installation <https://www.colour-science.org/installation-guide>
    tutorial
    how-to
    basics
    advanced
    Contributing <https://www.colour-science.org/contributing/>
    Changes <https://github.com/colour-science/colour/releases>
    bibliography
